# lapack
%define major 3
%define minor 9.0
%define libname %mklibname %{name} %{major}
%define develname %mklibname -d %{name}
%define staticname %mklibname -d %{name}-static
%define docname	%{name}-doc
%global shortver	3
%global mediumver	%{shortver}.8
%global build_ldflags ""

%if %{?__isa_bits:%{__isa_bits}}%{!?__isa_bits:32} == 64
%global arch64 1
%else
%global arch64 0
%endif

# blas
%define libblasname %mklibname blas %{major}
%define develblasname %mklibname blas -d
%define staticblasname %mklibname blas-static -d
%define docblasname blas-doc

Summary:	LAPACK libraries for linear algebra
Name:		lapack
Version:	%{major}.%{minor}
Release:	%mkrel 3
License:	BSD-like
Group:		Sciences/Mathematics
URL:		http://www.netlib.org/lapack/
Source0:	https://github.com/Reference-LAPACK/lapack/archive/v3.9.0.tar.gz#/lapack-3.9.0.tar.gz
Source1:	http://www.netlib.org/lapack/manpages.tgz
Source2: 	Makefile.blas
Source3:	Makefile.lapack
Source4:	http://www.netlib.org/lapack/lapackqref.ps
Source5:	http://www.netlib.org/blas/blasqr.ps
Source6:	Makefile.cblas

Patch3: lapack-3.9.0-make.inc.patch
Patch4: lapack-3.9.0-lapacke-shared.patch
Patch7: lapack-3.9.0-lapacke-tmglib.patch
Patch8: lapack-3.9.0-propagate-nan.patch

BuildRequires:	gcc-gfortran >= 8.2.0-0.5
%ifarch %ix86 x86_64
BuildRequires:	quadmath-devel >= 8.2.0-0.5
%endif
Obsoletes:	%{name} < 3.1.1

%description
LAPACK (Linear Algebra PACKage) is a standard library for numerical
linear algebra. LAPACK provides routines for solving systems of
simultaneous linear equations, least-squares solutions of linear
systems of equations, eigenvalue problems, and singular value
problems. Associated matrix factorizations (LU, Cholesky, QR, SVD,
Schur, and generalized Schur) and related computations (i.e.,
reordering of Schur factorizations and estimating condition numbers)
are also included. LAPACK can handle dense and banded matrices, but
not general sparse matrices. Similar functionality is provided for
real and complex matrices in both single and double precision. LAPACK
is coded in Fortran77 and built with gcc.

The lapack package provides the dynamic libraries for LAPACK/BLAS.

%package -n %{libname}
Summary:	LAPACK libraries for linear algebra
Group:		Sciences/Mathematics
Provides:	lib%{name} = %{version}-%{release}
Obsoletes:	%{_lib}lapack3.2
Obsoletes:	%{_lib}lapack3.1

%description -n %{libname}
LAPACK (Linear Algebra PACKage) is a standard library for numerical
linear algebra. LAPACK provides routines for solving systems of
simultaneous linear equations, least-squares solutions of linear
systems of equations, eigenvalue problems, and singular value
problems. Associated matrix factorizations (LU, Cholesky, QR, SVD,
Schur, and generalized Schur) and related computations (i.e.,
reordering of Schur factorizations and estimating condition numbers)
are also included. LAPACK can handle dense and banded matrices, but
not general sparse matrices. Similar functionality is provided for
real and complex matrices in both single and double precision. LAPACK
is coded in Fortran77 and built with gcc.

The lapack package provides the dynamic libraries for LAPACK/BLAS.

%package -n %{develname}
Summary:	LAPACK devel library
Group:		Sciences/Mathematics
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Obsoletes:	%mklibname -d %{name} %{major}
Requires:	blas-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the headers and development libraries
necessary to develop or compile applications using lapack.

%package -n %{staticname}
Summary: LAPACK static libraries
Group: Sciences/Mathematics
Requires: lapack-devel = %{version}-%{release}

%description -n %{staticname}
LAPACK static libraries.

%package -n %{docname}
Summary:	Documentation for LAPACK
Group:		Sciences/Mathematics

%description -n %{docname}
Man pages / documentation for LAPACK.

%package -n %{libblasname}
Summary:	The BLAS (Basic Linear Algebra Subprograms) library
Group:		Sciences/Mathematics
Provides:	libblas = %{version}-%{release}
Obsoletes:	%{mklibname blas 1.1}
Obsoletes:	%{_lib}blas3.2
Obsoletes:	%{_lib}blas3.1

%description -n %{libblasname}
BLAS (Basic Linear Algebra Subprograms) is a standard library which
provides a number of basic algorithms for numerical algebra. Man
pages for blas are available in the blas-man package.

%package -n %{develblasname}
Summary:	BLAS development libraries
Group:		Sciences/Mathematics
Requires:	%{libblasname} = %{version}-%{release}
Provides:	blas-devel = %{version}-%{release}
Provides:	libblas-devel = %{version}-%{release}
Obsoletes:	%{mklibname blas 1.1 -d} < 3.1.1
Requires:	gcc-gfortran

%description -n %{develblasname}
BLAS development libraries for applications that link statically.

%package -n %{staticblasname}
Summary: BLAS static libraries
Group: Sciences/Mathematics
Requires: blas-devel = %{version}-%{release}

%description -n %{staticblasname}
BLAS static libraries.

%package -n %{docblasname}
Summary:	Documentation for BLAS
Group:		Sciences/Mathematics

%description -n %{docblasname}
Man pages / documentation for BLAS.

%prep
%setup -q
%setup -q -D -T -a1
%patch3 -p1 -b .fedora
%patch4 -p1 -b .shared
%patch7 -p1 -b .tmglib

#need https://github.com/Reference-LAPACK/lapack/pull/390
#need https://github.com/xianyi/OpenBLAS/pull/2442
%patch8 -p1 -b .propagate-na

mkdir manpages
mv man/ manpages/

cp -f INSTALL/make.inc.gfortran make.inc
cp -f %{SOURCE2} BLAS/SRC/Makefile
cp -f %{SOURCE3} SRC/Makefile
cp -f %{SOURCE6} CBLAS/src/Makefile

sed -i "s|@SHORTVER@|%{shortver}|g" BLAS/SRC/Makefile
sed -i "s|@SHORTVER@|%{shortver}|g" SRC/Makefile
sed -i "s|@SHORTVER@|%{shortver}|g" LAPACKE/Makefile
sed -i "s|@SHORTVER@|%{shortver}|g" CBLAS/src/Makefile
sed -i "s|@LONGVER@|%{version}|g" BLAS/SRC/Makefile
sed -i "s|@LONGVER@|%{version}|g" SRC/Makefile
sed -i "s|@LONGVER@|%{version}|g" LAPACKE/Makefile
sed -i "s|@LONGVER@|%{version}|g" CBLAS/src/Makefile

%build
export FC=gfortran
export CFLAGS="%{optflags} -funroll-all-loops"
export FFLAGS=$CFLAGS

# Build BLAS
pushd BLAS/SRC
%make_build FFLAGS="$FFLAGS" dcabs1.o
%make_build FFLAGS="$FFLAGS" CFLAGS="$CFLAGS" static
cp libblas.a ${RPM_BUILD_DIR}/%{name}-%{version}/
%make_build clean
%make_build FFLAGS="$FFLAGS -Os -fPIC" dcabs1.o
%make_build FFLAGS="$FFLAGS -fPIC" CFLAGS="$CFLAGS -fPIC" LDFLAGS="%{build_ldflags}" shared
cp libblas.so.%{version} ${RPM_BUILD_DIR}/%{name}-%{version}/
popd

ln -s libblas.so.%{version} libblas.so

# Some files don't like -O2, but -Os is fine
RPM_OPT_SIZE_FLAGS=$(echo $RPM_OPT_FLAGS | sed 's|-O2|-Os|')

# Build CBLAS
cp CBLAS/include/cblas_mangling_with_flags.h.in CBLAS/include/cblas_mangling.h
pushd CBLAS/src
FFLAGS="$RPM_OPT_FLAGS" CFLAGS="$RPM_OPT_FLAGS -I../include" make static
cp libcblas.a ${RPM_BUILD_DIR}/%{name}-%{version}/
make clean
FFLAGS="$RPM_OPT_FLAGS -fPIC" CFLAGS="$RPM_OPT_FLAGS -fPIC -I../include" LDFLAGS="%{build_ldflags}" make shared
cp libcblas.so.%{version} ${RPM_BUILD_DIR}/%{name}-%{version}/
popd

ln -s libcblas.so.%{version} libcblas.so

# Build the static dlamch, dsecnd, lsame, second, slamch bits
pushd INSTALL
%make_build FFLAGS_NOOPT="$FFLAGS -Os" FFLAGS="$FFLAGS"
popd

# Build the static lapack library
pushd SRC
%make_build FFLAGS="$FFLAGS" CFLAGS="$CFLAGS" FFLAGS_NOOPT="$CFLAGS -Os" static
cp liblapack.a ${RPM_BUILD_DIR}/%{name}-%{version}/
popd

# Buuld the static with pic dlamch, dsecnd, lsame, second, slamch bits
pushd INSTALL
%make_build clean
%make_build FFLAGS_NOOPT="$CFLAGS -Os -fPIC" FFLAGS="$FFLAGS -fPIC"
popd

# Build the static with pic lapack library
pushd SRC
%make_build clean
%make_build FFLAGS="$FFLAGS -fPIC" CFLAGS="$CFLAGS -fPIC" FFLAGS_NOOPT="$CFLAGS -Os -fPIC" static
cp liblapack.a ${RPM_BUILD_DIR}/%{name}-%{version}/liblapack_pic.a
popd

# Build the shared dlamch, dsecnd, lsame, second, slamch bits
pushd INSTALL
%make_build clean
%make_build FFLAGS_NOOPT="$FFLAGS -Os -fPIC" FFLAGS="$FFLAGS -fPIC"
popd

# Build the shared lapack library
pushd SRC
%make_build clean
%make_build FFLAGS="$FFLAGS -fPIC" CFLAGS="$CFLAGS -fPIC" FFLAGS_NOOPT="$CFLAGS -Os -fPIC" LDFLAGS="%{build_ldflags}" shared
cp liblapack.so.%{version} ${RPM_BUILD_DIR}/%{name}-%{version}/
popd

ln -s liblapack.so.%{version} liblapack.so

# Build the lapacke libraries
%make_build FFLAGS="$RPM_OPT_FLAGS -fPIC" FFLAGS_NOOPT="$RPM_OPT_O_FLAGS -fPIC" tmglib
pushd LAPACKE
%make_build clean
%make_build CFLAGS="$RPM_OPT_FLAGS" BUILD_DEPRECATED="true" lapacke
%make_build clean
%make_build CFLAGS="$RPM_OPT_FLAGS -fPIC" BUILD_DEPRECATED="true" LDFLAGS="%{build_ldflags}" shlib
popd

cp %{SOURCE4} lapackqref.ps
cp %{SOURCE5} blasqr.ps

%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_mandir}/man3

for f in liblapack.so.%{version} libblas.so.%{version} libcblas.so.%{version} liblapacke.so.%{version} libblas.a libcblas.a liblapack.a liblapack_pic.a liblapacke.a; do
  cp -f $f %{buildroot}%{_libdir}/$f
done

# Blas manpages
pushd manpages/
mkdir -p blas/man/man3
cd man/man3/
mv caxpy.f.3 caxpy.3 ccopy.f.3 ccopy.3 cdotc.f.3 cdotc.3 cdotu.f.3 cdotu.3 cgbmv.f.3 cgbmv.3 \
cgemm.f.3 cgemm.3 cgemv.f.3 cgemv.3 cgerc.f.3 cgerc.3 cgeru.f.3 cgeru.3 chbmv.f.3 chbmv.3 \
chemm.f.3 chemm.3 chemv.f.3 chemv.3 cher.f.3 cher.3 cher2.f.3 cher2.3 cher2k.f.3 cher2k.3 \
cherk.f.3 cherk.3 chpmv.f.3 chpmv.3 chpr.f.3 chpr.3 chpr2.f.3 chpr2.3 crotg.f.3 crotg.3 \
cscal.f.3 cscal.3 csrot.f.3 csrot.3 csscal.f.3 csscal.3 cswap.f.3 cswap.3 csymm.f.3 \
csymm.3 csyr2k.f.3 csyr2k.3 csyrk.f.3 csyrk.3 ctbmv.f.3 ctbmv.3 ctbsv.f.3 ctbsv.3 ctpmv.f.3 \
ctpmv.3 ctpsv.f.3 ctpsv.3 ctrmm.f.3 ctrmm.3 ctrmv.f.3 ctrmv.3 ctrsm.f.3 ctrsm.3 ctrsv.f.3 \
ctrsv.3 dasum.f.3 dasum.3 daxpy.f.3 daxpy.3 dcabs1.f.3 dcabs1.3 dcopy.f.3 dcopy.3 ddot.f.3 \
ddot.3 dgbmv.f.3 dgbmv.3 dgemm.f.3 dgemm.3 dgemv.f.3 dgemv.3 dger.f.3 dger.3 dnrm2.f.3 \
dnrm2.3 drot.f.3 drot.3 drotg.f.3 drotg.3 drotm.f.3 drotm.3 drotmg.f.3 drotmg.3 dsbmv.f.3 \
dsbmv.3 dscal.f.3 dscal.3 dsdot.f.3 dsdot.3 dspmv.f.3 dspmv.3 dspr.f.3 dspr.3 dspr2.f.3 \
dspr2.3 dswap.f.3 dswap.3 dsymm.f.3 dsymm.3 dsymv.f.3 dsymv.3 dsyr.f.3 dsyr.3 dsyr2.f.3 \
dsyr2.3 dsyr2k.f.3 dsyr2k.3 dsyrk.f.3 dsyrk.3 dtbmv.f.3 dtbmv.3 dtbsv.f.3 dtbsv.3 dtpmv.f.3 \
dtpmv.3 dtpsv.f.3 dtpsv.3 dtrmm.f.3 dtrmm.3 dtrmv.f.3 dtrmv.3 dtrsm.f.3 dtrsm.3 dtrsv.f.3 \
dtrsv.3 dzasum.f.3 dzasum.3 dznrm2.f.3 dznrm2.3 icamax.f.3 icamax.3 idamax.f.3 idamax.3 \
isamax.f.3 isamax.3 izamax.f.3 izamax.3 lsame.3 sasum.f.3 sasum.3 saxpy.f.3 saxpy.3 \
scabs1.f.3 scabs1.3 scasum.f.3 scasum.3 scnrm2.f.3 scnrm2.3 scopy.f.3 scopy.3 sdot.f.3 sdot.3 \
sdsdot.f.3 sdsdot.3 sgbmv.f.3 sgbmv.3 sgemm.f.3 sgemm.3 sgemv.f.3 sgemv.3 sger.f.3 sger.3 \
snrm2.f.3 snrm2.3 srot.f.3 srot.3 srotg.f.3 srotg.3 srotm.f.3 srotm.3 srotmg.f.3 srotmg.3 \
ssbmv.f.3 ssbmv.3 sscal.f.3 sscal.3 sspmv.f.3 sspmv.3 sspr.f.3 sspr.3 sspr2.f.3 sspr2.3 \
sswap.f.3 sswap.3 ssymm.f.3 ssymm.3 ssymv.f.3 ssymv.3 ssyr.f.3 ssyr.3 ssyr2.f.3 ssyr2.3 \
ssyr2k.f.3 ssyr2k.3 ssyrk.f.3 ssyrk.3 stbmv.f.3 stbmv.3 stbsv.f.3 stbsv.3 stpmv.f.3 stpmv.3 \
stpsv.f.3 stpsv.3 strmm.f.3 strmm.3 strmv.f.3 strmv.3 strsm.f.3 strsm.3 strsv.f.3 strsv.3 \
xerbla.3 xerbla_array.3 zaxpy.f.3 zaxpy.3 zcopy.f.3 zcopy.3 \
zdotc.f.3 zdotc.3 zdotu.f.3 zdotu.3 zdrot.f.3 zdrot.3 zdscal.f.3 zdscal.3 zgbmv.f.3 zgbmv.3 \
zgemm.f.3 zgemm.3 zgemv.f.3 zgemv.3 zgerc.f.3 zgerc.3 zgeru.f.3 zgeru.3 zhbmv.f.3 zhbmv.3 \
zhemm.f.3 zhemm.3 zhemv.f.3 zhemv.3 zher.f.3 zher.3 zher2.f.3 zher2.3 zher2k.f.3 zher2k.3 \
zherk.f.3 zherk.3 zhpmv.f.3 zhpmv.3 zhpr.f.3 zhpr.3 zhpr2.f.3 zhpr2.3 zrotg.f.3 zrotg.3 \
zscal.f.3 zscal.3 zswap.f.3 zswap.3 zsymm.f.3 zsymm.3 zsyr2k.f.3 zsyr2k.3 zsyrk.f.3 zsyrk.3 \
ztbmv.f.3 ztbmv.3 ztbsv.f.3 ztbsv.3 ztpmv.f.3 ztpmv.3 ztpsv.f.3 ztpsv.3 ztrmm.f.3 ztrmm.3 \
ztrmv.f.3 ztrmv.3 ztrsm.f.3 ztrsm.3 ztrsv.f.3 ztrsv.3 ../../blas/man/man3
cd ../..
popd

find manpages/blas/man/man3 -type f -printf "%{_mandir}/man3/%f*\n" > blasmans

# remove weird man pages
pushd manpages/man/man3
rm -rf _Users_julie*
popd

find manpages/man/man3 -type f -printf "%{_mandir}/man3/%f*\n" > lapackmans

cp -f manpages/blas/man/man3/* ${RPM_BUILD_ROOT}%{_mandir}/man3
cp -f manpages/man/man3/* ${RPM_BUILD_ROOT}%{_mandir}/man3

# Cblas headers
mkdir -p %{buildroot}%{_includedir}/cblas/
cp -a CBLAS/include/*.h %{buildroot}%{_includedir}/cblas/

# Lapacke headers
mkdir -p %{buildroot}%{_includedir}/lapacke/
cp -a LAPACKE/include/*.h %{buildroot}%{_includedir}/lapacke/

pushd ${RPM_BUILD_ROOT}%{_libdir}
ln -sf liblapack.so.%{version} liblapack.so
ln -sf liblapack.so.%{version} liblapack.so.%{shortver}
ln -sf liblapack.so.%{version} liblapack.so.%{mediumver}
ln -sf libblas.so.%{version} libblas.so
ln -sf libblas.so.%{version} libblas.so.%{shortver}
ln -sf libblas.so.%{version} libblas.so.%{mediumver}
ln -sf libcblas.so.%{version} libcblas.so
ln -sf libcblas.so.%{version} libcblas.so.%{shortver}
ln -sf libcblas.so.%{version} libcblas.so.%{mediumver}
ln -sf liblapacke.so.%{version} liblapacke.so
ln -sf liblapacke.so.%{version} liblapacke.so.%{shortver}
ln -sf liblapacke.so.%{version} liblapacke.so.%{mediumver}
popd

# pkgconfig
mkdir -p %{buildroot}%{_libdir}/pkgconfig/
cp -a lapack.pc.in %{buildroot}%{_libdir}/pkgconfig/lapack.pc
sed -i 's|@CMAKE_INSTALL_FULL_LIBDIR@|%{_libdir}|g' %{buildroot}%{_libdir}/pkgconfig/lapack.pc
sed -i 's|@CMAKE_INSTALL_FULL_INCLUDEDIR@|%{_includedir}|g' %{buildroot}%{_libdir}/pkgconfig/lapack.pc
sed -i 's|@LAPACK_VERSION@|%{version}|g' %{buildroot}%{_libdir}/pkgconfig/lapack.pc
cp -a BLAS/blas.pc.in %{buildroot}%{_libdir}/pkgconfig/blas.pc
sed -i 's|@CMAKE_INSTALL_FULL_LIBDIR@|%{_libdir}|g' %{buildroot}%{_libdir}/pkgconfig/blas.pc
sed -i 's|@CMAKE_INSTALL_FULL_INCLUDEDIR@|%{_includedir}|g' %{buildroot}%{_libdir}/pkgconfig/blas.pc
sed -i 's|@LAPACK_VERSION@|%{version}|g' %{buildroot}%{_libdir}/pkgconfig/blas.pc
cp -a LAPACKE/lapacke.pc.in %{buildroot}%{_libdir}/pkgconfig/lapacke.pc
sed -i 's|@CMAKE_INSTALL_FULL_LIBDIR@|%{_libdir}|g' %{buildroot}%{_libdir}/pkgconfig/lapacke.pc
sed -i 's|@CMAKE_INSTALL_FULL_INCLUDEDIR@|%{_includedir}/lapacke|g' %{buildroot}%{_libdir}/pkgconfig/lapacke.pc
sed -i 's|@LAPACK_VERSION@|%{version}|g' %{buildroot}%{_libdir}/pkgconfig/lapacke.pc
cp -a CBLAS/cblas.pc.in %{buildroot}%{_libdir}/pkgconfig/cblas.pc
sed -i 's|@CMAKE_INSTALL_FULL_LIBDIR@|%{_libdir}|g' %{buildroot}%{_libdir}/pkgconfig/cblas.pc
sed -i 's|@CMAKE_INSTALL_FULL_INCLUDEDIR@|%{_includedir}/cblas|g' %{buildroot}%{_libdir}/pkgconfig/cblas.pc
sed -i 's|@LAPACK_VERSION@|%{version}|g' %{buildroot}%{_libdir}/pkgconfig/cblas.pc

%files -n %{libname}
%{_libdir}/liblapack.so.*
%{_libdir}/liblapacke.so.*

%files -n %{develname}
%{_includedir}/lapacke/
%{_libdir}/liblapack.so
%{_libdir}/liblapacke.so
%{_libdir}/pkgconfig/lapack.pc
%{_libdir}/pkgconfig/lapacke.pc

%files -n %{staticname}
%{_libdir}/liblapack.a
%{_libdir}/liblapack_pic.a
%{_libdir}/liblapacke.a

%files -n %{docname} -f lapackmans
%doc README.md lapackqref.ps

%files -n %{libblasname}
%{_libdir}/libblas.so.*
%{_libdir}/libcblas.so.*

%files -n %{develblasname}
%{_includedir}/cblas/
%{_libdir}/libblas.so
%{_libdir}/libcblas.so
%{_libdir}/pkgconfig/blas.pc
%{_libdir}/pkgconfig/cblas.pc

%files -n %{staticblasname}
%{_libdir}/libblas*.a
%{_libdir}/libcblas*.a

%files -n %{docblasname} -f blasmans
%doc blasqr.ps


%changelog
* Sun Nov 01 2020 joequant <joequant> 3.9.0-3.mga8
+ Revision: 1641097
- fix nan propagation bug needed for R-base
  This fixes a NA propagation bug which is needed to fix in order
  to make R-base work with external lapack

* Fri Feb 28 2020 daviddavid <daviddavid> 3.9.0-2.mga8
+ Revision: 1551735
- sync Makefile.lapack with fedora thus fixing: "liblapack.so.3: undefined symbol: dcombssq_"

* Wed Feb 26 2020 joequant <joequant> 3.9.0-1.mga8
+ Revision: 1550723
- update to 3.9.0

* Thu Feb 13 2020 umeabot <umeabot> 3.8.0-5.mga8
+ Revision: 1513867
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 3.8.0-4.mga7
+ Revision: 1298712
- Mageia 7 Mass Rebuild

* Sat Jul 28 2018 tmb <tmb> 3.8.0-3.mga7
+ Revision: 1245623
- rebuild for gcc 8.2

* Sat Jun 23 2018 joequant <joequant> 3.8.0-2.mga7
+ Revision: 1239183
- update with fixes from fedora

* Thu Jun 21 2018 joequant <joequant> 3.8.0-1.mga7
+ Revision: 1238689
- upgrade to 3.8.0

* Mon Oct 09 2017 joequant <joequant> 3.7.1-1.mga7
+ Revision: 1170376
- reset manpages
- fix manpages
- fix manpages
- upgrade to 3.7.1

* Sat Sep 02 2017 joequant <joequant> 3.6.1-2.mga7
+ Revision: 1150556
- recompile with new gcc

* Wed Aug 10 2016 luigiwalser <luigiwalser> 3.6.1-1.mga6
+ Revision: 1045279
- 3.6.1

* Sun Dec 20 2015 lmenut <lmenut> 3.6.0-1.mga6
+ Revision: 912749
- update to 3.6.0

* Wed Oct 15 2014 umeabot <umeabot> 3.5.0-3.mga5
+ Revision: 745982
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.5.0-2.mga5
+ Revision: 681267
- Mageia 5 Mass Rebuild

* Sun Feb 16 2014 luigiwalser <luigiwalser> 3.5.0-1.mga5
+ Revision: 592520
- 3.5.0
- rediff patch 0

* Fri Oct 18 2013 umeabot <umeabot> 3.4.2-4.mga4
+ Revision: 506798
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 3.4.2-3.mga3
+ Revision: 356638
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 29 2012 rtp <rtp> 3.4.2-2.mga3
+ Revision: 336031
- Fix build-dep

* Sun Oct 07 2012 luigiwalser <luigiwalser> 3.4.2-1.mga3
+ Revision: 303165
- 3.4.2

* Sun Aug 26 2012 lmenut <lmenut> 3.4.1-1.mga3
+ Revision: 284220
- update to 3.4.1

* Tue May 08 2012 fwang <fwang> 3.4.0-2.mga2
+ Revision: 234874
- drop invalid obsolete

* Wed Dec 21 2011 lmenut <lmenut> 3.4.0-1.mga2
+ Revision: 185402
- update to 3.4.0
- add BuildRequires quadmath-devel
+ tv <tv>
- new release
- drop patch 1 (merged)

* Sun Apr 17 2011 lmenut <lmenut> 3.3.0-1.mga1
+ Revision: 87240
- update to 3.3.0

* Thu Jan 13 2011 ahmad <ahmad> 3.2.2-2.mga1
+ Revision: 8270
- make the conflict generic
- imported package lapack

